<?php

namespace Drupal\commerce_boxnow\Plugin\Commerce\CheckoutPane;

use Drupal\commerce_checkout\Annotation\CommerceCheckoutPane;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\Component\Utility\Html;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a custom BOX NOW shipping summary pane.
 *
 * @CommerceCheckoutPane(
 *   id = "commerce_boxnow_shipping_summary",
 *   label = @Translation("BOX NOW Shipping Summary"),
 *   default_step = "review",
 * )
 */
class BoxNowShippingSummary extends CheckoutPaneBase {

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $shipments = $this->order->get('shipments')->referencedEntities();
    if (!isset($shipments[0])) {
      return [];
    }
    $selected_shipping_plugin = $shipments[0]->getShippingMethod()?->getPlugin();
    if (!$selected_shipping_plugin) {
      return [];
    }

    $boxnow_shipping_summary = $selected_shipping_plugin->getConfiguration()['rate_label'];

    if ($selected_shipping_plugin->getPluginId() === 'boxnow_shipping') {
      $locker_address = $shipments[0]->getData('locker_address');
      $locker_postal_code = $shipments[0]->getData('locker_postal_code');
      if ($locker_address && $locker_postal_code) {
        $boxnow_shipping_summary .= ' ('. t('Locker') .': ' . Html::escape($locker_address) . ', ' . Html::escape($locker_postal_code) . ')';
      }
      else {
        \Drupal::logger('commerce_boxnow')->warning('Locker details are missing for BoxNow shipping.');
      }
    }

    // Build the summary markup.
    $summary = [
      'boxnow_method' => [
        '#markup' => '<p class=" shipping-boxnow_shipping">' . Html::escape($boxnow_shipping_summary) . '</p>',
      ],
    ];

    // Add the summary fieldset.
    $pane_form['boxnow_summary'] = [
      '#type' => 'fieldset',
      '#title' => t('BOX NOW Shipping Summary'),
    ];

    // Attach the shipping summary to the pane form.
    $pane_form['boxnow_summary']['summary'] = $summary;

    return $pane_form;
  }
}
